package Message::Passing::Collectd;
use strict;
use warnings;

our $VERSION = '0.003';

1;

=head1 NAME

Message::Passing::Collectd - a suite of adaptors between Message::Passing and collectd.

=head1 DESCRIPTION

This package is a placeholder for adaptors between L<Message::Passing> and L<collectd|http://collectd.org>.

Please see L<Collectd::Plugin::Write::Message::Passing> (known working) and
L<Collectd::Plugin::Read::Message::Passing> (sketch currently).

=head1 AUTHOR

Tomas Doran (t0m) C<< <bobtfish@bobtfish.net> >>

=head1 COPYRIGHT & LICENSE

Copyright 2012 the above author.

Licensed under the same terms a perl itself.

=cut

